import click

from mosamatic.tasks import CreatePngsFromSegmentationsTask
from mosamatic.utils import param_dict_from_params


@click.command(help='Create PNG images from segmentation files')
@click.option(
    '--input', 
    required=True, 
    type=click.Path(exists=True), 
    help='Input directory to segmentation files'
)
@click.option(
    '--output', 
    required=True, 
    type=click.Path(), 
    help='Output directory for PNG images'
)
@click.option(
    '--params', 
    multiple=True,
    required=True, 
    type=click.Path(), 
    help='Parameters: fig_width (default: 10), fig_height (default: 10)'
)
@click.option(
    '--overwrite', 
    type=click.BOOL, 
    default=False, 
    help='Overwrite (true/false)'
)
def createpngsfromsegmentations(input, output, params, overwrite):
    """
    Creates PNG images from segmentations files generated by the "segmentmusclefatl3" command.
    
    Parameters
    ----------
    input : str
        Path to directory with segmentation files.
    
    output : str
        Path to output directory where PNG images will be stored.

    params: dict
        Dictionary of parameters:

        {
            'fig_width': '10',
            'fig_height': '10',
        }
    
    overwrite : bool
        Overwrite contents output directory true/false
    """
    params = param_dict_from_params(params)
    task = CreatePngsFromSegmentationsTask(input, output, params=params, overwrite=overwrite)
    task.run()